Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(936)

Unified Diff: components/sync/engine/passive_model_worker.h

Issue 2942773002: Task Scheduler API migration: change BrowserThreadModelWorker to SequencedModelWorker (Closed)
Patch Set: Updated more comments to reflect thread -> sequence migration. Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/engine/passive_model_worker.h
diff --git a/components/sync/engine/passive_model_worker.h b/components/sync/engine/passive_model_worker.h
index 11725df7e542e4c4533f34848503d3b4a1ab11cb..932966c6cd7df2f5f3690260160eb09382d891ac 100644
--- a/components/sync/engine/passive_model_worker.h
+++ b/components/sync/engine/passive_model_worker.h
@@ -11,15 +11,15 @@
namespace syncer {
// Implementation of ModelSafeWorker for passive types. All work is
// done on the same thread DoWorkAndWaitUntilDone (i.e., the sync
// thread).
class PassiveModelWorker : public ModelSafeWorker {
public:
PassiveModelWorker();
// ModelSafeWorker implementation.
ModelSafeGroup GetModelSafeGroup() override;
- bool IsOnModelThread() override;
+ bool IsOnModelSequence() override;
private:
~PassiveModelWorker() override;
« no previous file with comments | « components/sync/engine/model_safe_worker_unittest.cc ('k') | components/sync/engine/passive_model_worker.cc » ('j') | no next file with comments »
@@ -11,15 +11,15 @@
namespace syncer {
// Implementation of ModelSafeWorker for passive types. All work is
-// done on the same thread DoWorkAndWaitUntilDone (i.e., the sync
-// thread).
+// done on the same sequence DoWorkAndWaitUntilDone is called on (i.e. the same
+// sequence Sync runs on).
class PassiveModelWorker : public ModelSafeWorker {
public:

Powered by Google App Engine
This is Rietveld 408576698